// lib/index.ts
import { writeFile } from "node:fs/promises";
import { parse } from "node:path/posix";

// lib/utils.ts
import childProcess from "node:child_process";
import crypto from "node:crypto";
import { createLogger } from "vite";
var logger = createLogger();
var hash = crypto.hash ?? ((algorithm, data, outputEncoding) => crypto.createHash(algorithm).update(data).digest(outputEncoding));
function getHash(text, length = 8) {
  try {
    const h = hash("sha256", text, "hex").substring(0, length);
    if (length <= 64)
      return h;
    return h.padEnd(length, "_");
  } catch (e) {
    logger.error(`[getHash] - Error while creating hash: ${e}`);
    return "";
  }
}
function getGitHash() {
  try {
    return childProcess.execSync("git rev-parse --short HEAD").toString().replace("\n", "");
  } catch (e) {
    logger.error(`[getGitHash] - Error while getting git hash: ${e}`);
    return "";
  }
}

// lib/index.ts
function VitePluginBuildMetaData(opts = {}) {
  const {
    fileName = "meta"
  } = opts;
  let config;
  return {
    // this name will show up in warnings and errors
    name: "vite-plugin-build-metadata",
    apply: "build",
    enforce: "post",
    configResolved(resolvedConfig) {
      config = resolvedConfig;
    },
    writeBundle: async (options, bundle) => {
      const metaFilename = `${options.dir}/${parse(fileName).name}.json`;
      const metaData = {
        buildHash: getHash(JSON.stringify(bundle)),
        commitHash: getGitHash(),
        date: (/* @__PURE__ */ new Date()).toJSON()
      };
      await writeFile(
        metaFilename,
        JSON.stringify(metaData, null, 2)
      );
      config.logger.info(`
\u2728 [vite-plugin-build-metadata] - Hash has been created in ${fileName}.json
`);
    }
  };
}
export {
  VitePluginBuildMetaData,
  VitePluginBuildMetaData as default,
  getGitHash,
  getHash
};
